@@ -23,6 +23,7 @@ from tencentcloud.ocr.v20181119 import models
 class OcrClient(AbstractClient):
     _apiVersion = '2018-11-19'
     _endpoint = 'ocr.tencentcloudapi.com'
+    _service = 'ocr'
 
 
     def AdvertiseOCR(self, request):
@@ -1942,7 +1943,9 @@ class OcrClient(AbstractClient):
 
 
     def VerifyBasicBizLicense(self, request):
-        """本接口支持营业执照信息的识别与准确性核验。您可以通过输入营业执照关键字段或传入营业执照图片提供所需的验证信息，接口返回真实的企业工商照面信息及核验结果，包括统一社会信用代码、经营期限、法人姓名、经营状态、经营业务范围、状态信息、原注册号、要核验的工商注册号、工商注册号、要核验的企业名称、企业名称、要核验的注册住址、注册住址、核验结果、注册资本共16个基础字段。
+        """本接口支持营业执照信息的识别与准确性核验。
+
+        您可以通过输入营业执照注册号或营业执照图片（若两者都输入则只用注册号做查询）进行核验，接口返回查询到的工商照面信息，并比对要校验的字段与查询结果的一致性。查询到工商信息包括：统一社会信用代码、经营期限、法人姓名、经营状态、经营业务范围、注册资本等。
 
         :param request: Request instance for VerifyBasicBizLicense.
         :type request: :class:`tencentcloud.ocr.v20181119.models.VerifyBasicBizLicenseRequest`
@@ -1970,8 +1973,11 @@ class OcrClient(AbstractClient):
 
 
     def VerifyBizLicense(self, request):
-        """本接口支持营业执照信息的识别与准确性核验，返回的营业执照信息比营业执照识别及核验（基础版）接口更详细。
-        您可以通过输入营业执照关键字段或传入营业执照图片提供所需的验证信息，接口返回真实的企业工商照面信息及核验结果，包括统一社会信用代码、组织机构代码、经营期限、法人姓名、经营状态、经营业务范围及方式、注册资金、注册币种、登记机关、开业日期、企业（机构）类型、注销日期、吊销日期、许可经营项目、一般经营项目、核准时间、省、地级市、区/县、住所所在行政区划代码、行业门类代码、行业门类名称、国民经济行业代码、国民经济行业名称、经营（业务）范围、要核验的工商注册号、工商注册号、要核验的企业名称、企业名称、要核验的注册住址、注册住址、核验结果共33个详细字段。
+        """本接口支持营业执照信息的识别与准确性核验，返回的真实工商照面信息比营业执照识别及核验（基础版）接口更详细。
+
+        您可以输入营业执照注册号或营业执照图片（若两者都输入则只用注册号做查询），接口返回查询到的工商照面信息，并比对要校验的字段与查询结果的一致性。
+
+        查询到工商信息包括：统一社会信用代码、组织机构代码、经营期限、法人姓名、经营状态、经营业务范围及方式、注册资金、注册币种、登记机关、开业日期、企业（机构）类型、注销日期、吊销日期、许可经营项目、一般经营项目、核准时间、省、地级市、区/县、住所所在行政区划代码、行业门类代码、行业门类名称、国民经济行业代码、国民经济行业名称、经营（业务）范围等。
 
         :param request: Request instance for VerifyBizLicense.
         :type request: :class:`tencentcloud.ocr.v20181119.models.VerifyBizLicenseRequest`
